==> design-system-core-1.3.0.tgz: package/stories/forms/PasswordInput.stories.js <==
import classNames from 'classnames'

/**
 * The standard form password input, shown here with a label, and where applicable an error message
 *
 * * **Note:** Javascript will be handled in the application to show/hide the password
 * */

export default {
  title: 'Components/Form/PasswordInput',
  tags: ['autodocs'],
  argTypes: {
    show: {
      control: 'boolean',
    },
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    show: false,
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const PasswordTemplate = ({ show, disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_container = classNames('rpf-input-password__container',{
    'rpf-input-password__container--full-width': fullWidth,
    'rpf-input-password__container--error': error,
    'rpf-input-password__container--disabled': disabled,
    'rpf-input-password__container--readonly': readonly,
  })
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-password', {
    'rpf-input--full-width': fullWidth,
    'rpf-input--error': error,
  })
  const classnames_button = classNames('rpf-button rpf-button--tertiary rpf-input-password__button', {
    'rpf-button--disabled': disabled,
    'rpf-input-password__button--error': error,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="password" class="${classnames_label}">
        What is your password?
        <small class="rpf-label__hint">Please enter your password</small>
      </label>
      <div class="${classnames_container}">
        <input type="${ show ? 'text' : 'password'}" id="password" name="password" class="${classnames_text}"${
          disabled ? ' disabled' : ''
        }${readonly ? ' readonly' : ''} value="password">
        <button class="${classnames_button}"${disabled ? ' disabled' : ''}>
          ${show ? 'Hide' : 'Show'}
        </button>
      </div>
    ${
      error
        ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">error</span>Error: Your password is required</div>'
        : ''
    }
    <a href="#" class="rpf-input-password__forgot">Forgot password?</a>
    </div>
  `
}

export const Default = PasswordTemplate.bind({})
Default.args = {}

export const Show = PasswordTemplate.bind({})
Show.args = {
  show: true,
}

export const Disabled = PasswordTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Readonly = PasswordTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Error = PasswordTemplate.bind({})
Error.args = {
  error: true,
}

export const FullWidth = PasswordTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

==> design-system-core-1.3.3.tgz: package/stories/forms/PasswordInput.stories.js <==
import classNames from 'classnames'

/**
 * The standard form password input, shown here with a label, and where applicable an error message
 *
 * * **Note:** Javascript will be handled in the application to show/hide the password
 * */

export default {
  title: 'Components/Form/PasswordInput',
  tags: ['autodocs'],
  argTypes: {
    show: {
      control: 'boolean',
    },
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    show: false,
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const PasswordTemplate = ({ show, disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_container = classNames('rpf-input-password__container',{
    'rpf-input-password__container--full-width': fullWidth,
    'rpf-input-password__container--error': error,
    'rpf-input-password__container--disabled': disabled,
    'rpf-input-password__container--readonly': readonly,
  })
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-password', {
    'rpf-input--full-width': fullWidth,
    'rpf-input--error': error,
  })
  const classnames_button = classNames('rpf-button rpf-button--tertiary rpf-input-password__button', {
    'rpf-button--disabled': disabled,
    'rpf-input-password__button--error': error,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="password" class="${classnames_label}">
        What is your password?
        <small class="rpf-label__hint">Please enter your password</small>
      </label>
      <div class="${classnames_container}">
        <input type="${ show ? 'text' : 'password'}" id="password" name="password" class="${classnames_text}"${
          disabled ? ' disabled' : ''
        }${readonly ? ' readonly' : ''} value="password">
        <button class="${classnames_button}"${disabled ? ' disabled' : ''} type="button">
          ${show ? 'Hide' : 'Show'}
        </button>
      </div>
    ${
      error
        ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">error</span>Error: Your password is required</div>'
        : ''
    }
    <a href="#" class="rpf-input-password__forgot">Forgot password?</a>
    </div>
  `
}

export const Default = PasswordTemplate.bind({})
Default.args = {}

export const Show = PasswordTemplate.bind({})
Show.args = {
  show: true,
}

export const Disabled = PasswordTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Readonly = PasswordTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Error = PasswordTemplate.bind({})
Error.args = {
  error: true,
}

export const FullWidth = PasswordTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}
